@@ -1,11 +1,14 @@
-from django.utils import simplejson as json
 import abc
+import json as js
 
 from .exceptions import HttpError
 from .status import HTTP_400_BAD_REQUEST
 from .tools import FrozenDict
 
 
+__all__ = 'FormParser', 'JSONParser', 'RawParser', 'XMLParser', 'AbstractParser'
+
+
 class AbstractParser(object):
     " Base class for parsers. "
 
@@ -52,7 +55,7 @@ class JSONParser(AbstractParser):
     @staticmethod
     def parse(request):
         try:
-            return json.loads(request.body)
+            return js.loads(request.body)
         except ValueError, e:
             raise HttpError('JSON parse error - %s'.format(e),
                             status=HTTP_400_BAD_REQUEST)
@@ -62,25 +65,3 @@ class XMLParser(RawParser):
     " Parse user data from XML. "
 
     media_type = 'application/xml'
-
-
-try:
-    from bson import BSON
-
-    class BSONParser(AbstractParser):
-        """ Parse user data from bson.
-            http://en.wikipedia.org/wiki/BSON
-        """
-
-        media_type = 'application/bson'
-
-        @staticmethod
-        def parse(request):
-            try:
-                return BSON(request.body).decode()
-            except ValueError, e:
-                raise HttpError('BSON parse error - %s'.format(e),
-                                status=HTTP_400_BAD_REQUEST)
-
-except ImportError:
-    pass
